# -*- coding: utf-8 -*-


from tornado.web import UIModule


class Script(UIModule):
    def render(self, origin, compress=None, *args, **kwargs):
        cdn = self.handler.cdn
        debug = self.handler.js_debug

        js_version = self.handler.js_version

        to_show = None

        buff = ''

        if debug or compress is None:
            if isinstance(origin, str):
                to_show = [origin]
            else:
                to_show = origin
        else:
            if isinstance(compress, str):
                to_show = [compress]
            else:
                to_show = compress

        for i in to_show:
            buff += '<script src="' + cdn + i + '?v=' + js_version + '"></script>'
        pass

        return buff







